rm *~
rm *.o
rm *.ppu
rm *.rst
rm *.bak
rm winff.exe
rm winff
rm *.or
rm *.compiled
rm backup/*
rmdir backup
rm magnifier

